Module plot

Module plot 

Plot builders, axes, and rendering utilities. Axes, canvas rendering, and line/scatter convenience functions.

Structs

Axes
Axis limits, ticks, labels, and title for a plot.
Canvas
An image-backed plotting surface.
LineStyle
Styling for a connected line series.
MarkerStyle
Styling for a scatter marker series.
Plot
A high-level, image-backed plot builder.

Constants

DEFAULT_SIZE
Default image dimensions for a plot.

Functions

line_plot
Creates a line-plot image from a point list and explicit axis limits.
line_plot_with_width
Creates a line plot with a configurable stroke width.
line_plot_with_width_and_inset
Creates a line plot with explicit pixel insets and stroke width.
scatter_plot
Creates a scatter-plot image from a point list and explicit axis limits.
scatter_plot_with_size
Creates a scatter-plot image with a configurable marker size.
scatter_plot_with_size_and_inset
Creates a scatter-plot with explicit pixel insets and marker size.