Module ppm

Module ppm 

Binary PPM input/output support. Binary PPM (P6) encoding and decoding.

Re-exports

pub use crate::Image;
pub use crate::Pixel;

Functions

read
Reads a binary P6 PPM file with a maximum channel value of 255.
read_from
Reads a binary P6 PPM image from any buffered reader.
write
Writes an image as a binary P6 PPM file.
write_to
Writes an image to any writer in the binary P6 PPM format.