Plot builders, axes, and rendering utilities. Axes, canvas rendering, and line/scatter convenience functions.
Structs
- Axes
- Axis limits, ticks, labels, and title for a plot.
- Canvas
- An image-backed plotting surface.
- Line
Style - Styling for a connected line series.
- Marker
Style - Styling for a scatter marker series.
- Plot
- A high-level, image-backed plot builder.
Constants
- DEFAULT_
SIZE - Default image dimensions for a plot.
Functions
- line_
plot - Creates a line-plot image from a point list and explicit axis limits.
- line_
plot_ with_ width - Creates a line plot with a configurable stroke width.
- line_
plot_ with_ width_ and_ inset - Creates a line plot with explicit pixel insets and stroke width.
- scatter_
plot - Creates a scatter-plot image from a point list and explicit axis limits.
- scatter_
plot_ with_ size - Creates a scatter-plot image with a configurable marker size.
- scatter_
plot_ with_ size_ and_ inset - Creates a scatter-plot with explicit pixel insets and marker size.