Axes

Struct Axes 

pub struct Axes {
    pub xlim: (f64, f64),
    pub ylim: (f64, f64),
    pub xticks: Vec<f64>,
    pub yticks: Vec<f64>,
    pub xlabel: String,
    pub ylabel: String,
    pub title: String,
    /* private fields */
}
Axis limits, ticks, labels, and title for a plot.

Fields

xlim: (f64, f64)

Lower and upper x-axis limits.

ylim: (f64, f64)

Lower and upper y-axis limits.

xticks: Vec<f64>

Tick values shown on the x axis.

yticks: Vec<f64>

Tick values shown on the y axis.

xlabel: String

Label drawn beneath the plot.

ylabel: String

Label drawn beside the plot.

title: String

Plot title.

Implementations

Source

impl Axes

pub fn new() -> Self

Creates a new axis configuration with automatic limits and default labels.

pub fn from_limits(xlim: (f64, f64), ylim: (f64, f64)) -> Self

Creates a new axes configuration from explicit x/y limits.

pub fn x_limits(self, limits: (f64, f64)) -> Self

Sets the x-axis limits while keeping the builder pattern.

pub fn y_limits(self, limits: (f64, f64)) -> Self

Sets the y-axis limits while keeping the builder pattern.

pub fn labels(self, x: impl Into<String>, y: impl Into<String>) -> Self

Sets the x and y axis labels while keeping the builder pattern.

pub fn title(self, title: impl Into<String>) -> Self

Sets the plot title while keeping the builder pattern.

pub fn x_ticks(self, ticks: impl IntoIterator<Item = f64>) -> Self

Replaces the x-axis tick positions with explicit values.

pub fn y_ticks(self, ticks: impl IntoIterator<Item = f64>) -> Self

Replaces the y-axis tick positions with explicit values.

pub fn with_xlim(self, xlim: (f64, f64)) -> Self

Sets the x-axis limits and disables automatic rescaling for that axis.

pub fn with_ylim(self, ylim: (f64, f64)) -> Self

Sets the y-axis limits and disables automatic rescaling for that axis.

pub fn set_xlim(&mut self, xlim: (f64, f64))

Sets the x-axis limits and disables automatic rescaling for that axis.

pub fn set_ylim(&mut self, ylim: (f64, f64))

Sets the y-axis limits and disables automatic rescaling for that axis.

pub fn use_auto_xlim(&mut self)

Re-enables automatic fitting for the x-axis.

pub fn use_auto_ylim(&mut self)

Re-enables automatic fitting for the y-axis.

pub fn with_labels( self, xlabel: impl Into<String>, ylabel: impl Into<String>, ) -> Self

Sets the x and y axis labels.

pub fn with_title(self, title: impl Into<String>) -> Self

Sets the plot title.